/**
 * PETALS - PETALS Services Platform. Copyright (c) 2009 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * -------------------------------------------------------------------------
 * $Id:
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.bc.ejb;


import org.ow2.petals.bc.ejb.configuration.EjbConfiguration;
import org.ow2.petals.databinding.jaxb.service.Service;

/**
 * Utility class which stores an EJB object with many additionnal informations.
 *
 *
 * @author Charles Casadei - eBM WebSourcing
 */
public class EjbConnectionPoolElement {

    /**
     * The configuration for the given EJB.
     */
    private EjbConfiguration ejbConfiguration;

    /**
     * The EJB object.
     */
    private Object ejbObject;

    /**
     * The (databinding) service.
     */
    private Service service;

    /**
     * The SU ClassLoader.
     */
    private ClassLoader suClassLoader;

    /**
     * Default constructor.
     *
     * @param ejbConfiguration
     * @param ejbObject
     * @param service
     * @param suClassLoader
     */
    public EjbConnectionPoolElement(final EjbConfiguration ejbConfiguration,
            final Object ejbObject,
            final Service service,
            final ClassLoader suClassLoader) {
        this.setEjbConfiguration(ejbConfiguration);
        this.setEjbObject(ejbObject);
        this.setDatabindingEngine(service);
        this.setSuClassLoader(suClassLoader);
    }

    /**
     * Accessor on the EJB configuration.
     *
     * @return
     *      the EJB configuration
     */
    public EjbConfiguration getEjbConfiguration() {
        return this.ejbConfiguration;
    }

    /**
     * Setter on the EJB configuration.
     *
     * @param ejbConfiguration
     *      the new EJB configuration
     */
    public void setEjbConfiguration(EjbConfiguration ejbConfiguration) {
        this.ejbConfiguration = ejbConfiguration;
    }

    /**
     * Accessor on the EJB object.
     *
     * @return
     *      the EJB object
     */
    public Object getEjbObject() {
        return this.ejbObject;
    }

    /**
     * Setter on the EJB object that match the given configuration.
     *
     * @param ejbObject
     *      the EJB object that match the given configuration
     */
    public void setEjbObject(Object ejbObject) {
        this.ejbObject = ejbObject;
    }

    /**
     * Accessor on the databinding engine service used to call the EJB.
     *
     * @return
     *      the databinding engine service used to call the EJB
     */
    public Service getDatabindingService() {
        return this.service;
    }

    /**
     * Setter on the databinding service used to call the EJB.
     *
     * @param service
     *      the databinding used to call the EJB
     */
    public void setDatabindingEngine(Service service) {
        this.service = service;
    }

    /**
     * Accessor on the SU ClassLoader.
     *
     * @return
     *      the SU ClassLoader
     */
    public ClassLoader getSuClassLoader() {
        return this.suClassLoader;
    }

    /**
     * Setter for the SU ClassLoader.
     *
     * @param suClassLoader
     *      the SU ClassLoader
     */
    public void setSuClassLoader(ClassLoader suClassLoader) {
        this.suClassLoader = suClassLoader;
    }

    @Override
    public String toString() {
        StringBuilder toStringSB = new StringBuilder();
        toStringSB.append("configuration= " + this.getEjbConfiguration());
        toStringSB.append("\n");
        toStringSB.append("ejbObjectClass=" + this.getEjbObject().getClass().getCanonicalName());
        toStringSB.append("\n");
        toStringSB.append("databindingService=" + this.getDatabindingService());
        toStringSB.append("\n");
        toStringSB.append("suClassLoader=" + this.getSuClassLoader().toString());

        return toStringSB.toString();
    }
}