/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package org.ow2.petals.bc.ejb.configuration;

import org.ow2.petals.bc.ejb.constants.ProvidesConstants;
import org.ow2.petals.bc.ejb.exceptions.ConfigurationException;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;

/**
 * Helper class which helps (sic) building EjbConfiguration instances using
 * the values given in the SU ConfigurationExtensions.
 *
 * @author Charles Casadei - eBM WebSourcing
 */
public class EjbConfigurationBuilder {

    public static EjbConfiguration buildEjbConfiguration(
            final ConfigurationExtensions extensions,
            final String wsdlFileName,
            final String serviceName) throws ConfigurationException {


        //Checks if there are ConfigurationExtensions
        if (extensions == null) {
            StringBuilder errorSB = new StringBuilder();
            errorSB.append("Can't create ConfigurationExtensions from the given ");
            errorSB.append("JBI descriptor content : ");
            errorSB.append(" can't create configuration extensions from the given provides.");
            throw new ConfigurationException(errorSB.toString());
        }

        //Access to JNDI of the App server
        final String javaNamingFactoryInitial = extensions.get(ProvidesConstants.INITIAL_CONTEXT_FACTORY);
        final String javaNamingProviderUrl = extensions.get(ProvidesConstants.PROVIDER_URL);
        final String javaNamingFactoryUrlPkgs = extensions.get(ProvidesConstants.URL_PKG_PREFIX);

        //Access to the EJB
        final String ejbJndiName = extensions.get(ProvidesConstants.EJB_JNDI_NAME);
        final String ejbHomeInterface = extensions.get(ProvidesConstants.EJB_HOME_INTERFACE);
        final String ejbVersion = extensions.get(ProvidesConstants.EJB_VERSION);

        //Security features
        final String securityName = extensions.get(ProvidesConstants.SECURITY_NAME);
        final String securityPrincipal = extensions.get(ProvidesConstants.SECURITY_PRINCIPAL);
        final String securityCredentials = extensions.get(ProvidesConstants.SECURITY_CREDENTIALS);

        //Java to XML databinding configuration
        final String databindingEngine = extensions.get(ProvidesConstants.DATABINDING_ENGINE);

        //Creates a new EjbConnectionInfo instance
        return new EjbConfiguration(ejbJndiName, ejbHomeInterface, ejbVersion,
                javaNamingFactoryInitial, javaNamingFactoryUrlPkgs, javaNamingProviderUrl,
                securityName, securityPrincipal, securityCredentials,
                databindingEngine, wsdlFileName, serviceName);
    }
}
